Learn R Programming

radviz3d (version 2.3.0)

mrp: Max-Ratio Projection function

Description

function to project high-dimensional datasets to lower dimention with max-ratio projection.

Usage

mrp(data, cl, nproj = 4, message = TRUE, ...)

Value

A list with the elements

projected_df

The projected data with selected number of max-ratio directions.

pccumvar

The cummulative variance explained by the max-ratio principal components.

Arguments

data

The dataset to apply MRP. Each row is an observation.

cl

The class identification for each observation. The length of cl should be the same as the number of rows of data.

nproj

The number of max-ratio directions to be used in projecting the original data to the projected data.

message

Logical. Wheather to show the accumulative variance explained by the projection directions or not.

...

Additional arguments passed to internal functions.