3D Radial Visualization function
radialvis3d(
data,
domrp = TRUE,
doGtrans = FALSE,
sqrt_scale = FALSE,
cl = NULL,
color = NULL,
pch = 16,
colorblind = FALSE,
axes = FALSE,
point.cex = 1,
with.coord.labels = TRUE,
coord.labels = NULL,
coord.font = 2,
coord.cex = 1.1,
with.class.labels = TRUE,
class.labels = levels(factor(cl)),
class.labels.locations = NULL,
opt.anchor.order = FALSE,
alpha = 0.02,
lwd = 1,
axes.col = "black",
ret.trans = FALSE,
...
)A list with the elements
The result of MRP is the argument domrp = TRUE. See also mrp.
The dataset to visualize. Each row is an observation.
Logical. If true, MRP is applied to the origianl dataset. The default number of PCs used is npc = 4.
Logical. If true, Gtrans is applied to the origianl dataset. @seealso Gtrans.
Logical. If true, the distance of the points to be visualization will be augmented to squre root of the orginal distance to make points further away from the origin.
The class identification for each observation. The length of cl should be the same as the number of rows of data. If specified, different classes would be visualized with different colors.
The colors for different classes. If not specified, rainbow is used.
The point character to be used. It is an integer of a vector of integers of the same length of the nrow of the dataset. See points for a complete list of characters.
Logical.The colors for different classes.If true, poits are colorblind friendly.If false, rainbow is used.
Logical.If true, Cartesian axes would be plotted.
The size of the data point in RadViz3D. The default value is 1.
Logical. If true, labels of coordinates will be added to the visualization.
The labels for components of the dataset. When domrp = TRUE, the coord.labels will be changed to "Xi" representing the the ith direction obtained with MRP.
The font for labels of components.
The size of the labels of components.
Logical. If true, class labels will be added to the visualization.
The labels for different classes in the dataset.
Locations to put labels for each class. If not specified, an optimal location for each class would be calculated.
Logical. If true, the optimal order of anchor points corresponding to the components would be calculated. This is a very time consuming procedure. Not recommended if the number of components is larger then 6.
The alpha value that controls the transparency of the sphere in 3d visulization
The line width in the visualization
Colors of the axes, if needed to be displayed
Logical parameter, returns the Radviz3D transformation if TRUE
Some other parameters from mrp and Gtrans and rgl functions.
radialvis3d(data = iris[,-5], cl = iris[,5], domrp = TRUE)
Run the code above in your browser using DataLab