function to project high-dimensional datasets to lower dimention with max-ratio projection.
mrp(data, cl, nproj = 4, message = TRUE, ...)A list with the elements
The projected data with selected number of max-ratio directions.
The cummulative variance explained by the max-ratio principal components.
The dataset to apply MRP. Each row is an observation.
The class identification for each observation. The length of cl should be the same as the number of rows of data.
The number of max-ratio directions to be used in projecting the original data to the projected data.
Logical. Wheather to show the accumulative variance explained by the projection directions or not.
Additional arguments passed to internal functions.